@@ -124,8 +124,6 @@ class BaseApp(object):
         state = self.framework.get_session_data(request, 'state')
         if state != request_state:
             raise MismatchingStateError()
-        if state:
-            params['state'] = state
 
         code_verifier = self.framework.get_session_data(request, 'code_verifier')
         if code_verifier:
@@ -143,10 +141,9 @@ class BaseApp(object):
             params['request_token'] = request_token
         else:
             params = self._retrieve_oauth2_access_token_params(request, params)
-
-        redirect_uri = self.framework.get_session_data(request, 'redirect_uri')
-        if redirect_uri:
-            params['redirect_uri'] = redirect_uri
+            redirect_uri = self.framework.get_session_data(request, 'redirect_uri')
+            if redirect_uri:
+                params['redirect_uri'] = redirect_uri
 
         log.debug('Retrieve temporary data: {!r}'.format(params))
         return params
